@@ -1,4 +1,4 @@
-use internal::examples;
+use testing::examples;
 
 // smoelius: In each use of `examples::test_fuzz` below, the `target` argument is arbitrary. To
 // have a version of `examples::test_fuzz` that takes no arguments for just these tests would be
