@@ -1,8 +1,9 @@
 use anyhow::ensure;
-use internal::{dirs::corpus_directory_from_target, examples, testing::retry};
+use internal::dirs::corpus_directory_from_target;
 use predicates::prelude::*;
 use std::fs::{read_dir, remove_dir_all};
 use test_env_log::test;
+use testing::{examples, retry};
 
 const CRASH_TIMEOUT: &str = "60";
 
