@@ -1,8 +1,9 @@
-use internal::{dirs::corpus_directory_from_target, examples, testing::retry};
+use internal::dirs::corpus_directory_from_target;
 use predicates::prelude::*;
 use rlimit::Resource;
 use std::fs::remove_dir_all;
 use test_env_log::test;
+use testing::{examples, retry};
 
 // smoelius: MEMORY_LIMIT must be large enough for the build process to complete.
 const MEMORY_LIMIT: u64 = 1024 * 1024 * 1024;
